@@ -7,6 +7,7 @@ from duckling import (load_time_zones, parse_ref_time,
                       parse_lang, default_locale_lang, parse_locale,
                       parse_dimensions, parse, Context)
 from pydantic import BaseModel, Field
+from pymultirole_plugins.util import comma_separated_to_list
 from pymultirole_plugins.v1.annotator import AnnotatorParameters, AnnotatorBase
 from pymultirole_plugins.v1.schema import Document, Span, Annotation
 
@@ -31,8 +32,8 @@ class DucklingParameters(AnnotatorParameters):
                            description="Reference time zone to normalize date/time, must be a valid [time zone](https://en.wikipedia.org/wiki/List_of_tz_database_time_zones)")
     lang: str = Field("fr", description="Reference language")
     locale: Optional[str] = Field(None, description="Reference locale, default is the default locale of the language")
-    dimensions: Optional[List[Dimension]] = Field([Dimension.amount_of_money, Dimension.time],
-                                                  description="""List of [Duckling](https://github.com/facebook/duckling) dimensions to consider, to be chosen among:<br/>
+    dimensions: Optional[str] = Field("amount-of-money,time",
+                                      description="""Comma-separated list of [Duckling](https://github.com/facebook/duckling) dimensions to consider, to be chosen among:<br/>
         <li>`amount-of-money`: Measures an amount of money such as *$20*, *30 euros*.
         <li>`credit-card-number`: Captures a credit card number.
         <li>`distance`: Captures a distance in miles or kilometers such as *5km*, *5 miles* and *12m*.
@@ -63,8 +64,14 @@ class DucklingAnnotator(AnnotatorBase):
         # Create parsing context with time and language information
         context = get_context(params.time_zone, params.lang, params.locale)
 
-        # Define dimensions to look-up for
-        valid_dimensions = [d.value for d in params.dimensions]
+        # Define dimensions to look-up for, check if they are valid names
+        valid_dimensions = []
+        for d in comma_separated_to_list(params.dimensions):
+            try:
+                Dimension(d)
+                valid_dimensions.append(d)
+            except ValueError:
+                pass
 
         # Parse dimensions to use
         output_dims = parse_dimensions(valid_dimensions)
